@@ -1,11 +1,10 @@
-# This program is free software, distributed under the same terms as 
-# Parrot.
-
 package File::Find::Object::PathComp;
 
 use strict;
 use warnings;
 
+use integer;
+
 use base 'File::Find::Object::Base';
 
 use Class::XSAccessor
@@ -23,7 +22,9 @@ use Class::XSAccessor
                 _traverse_to
             ))
         ) 
-    }
+    },
+    getters => { _inodes => '_inodes' },
+    setters => { _set_inodes => '_inodes' },
     ;
 
 use File::Spec;
@@ -152,3 +153,20 @@ accessors, and is for File::Find::Object's internal use.
 =head1 SEE ALSO
 
 L<File::Find::Object>
+
+=head1 LICENSE
+
+Copyright (C) 2005, 2006 by Olivier Thauvin
+
+This package is free software; you can redistribute it and/or modify it under 
+the following terms:
+
+1. The GNU General Public License Version 2.0 - 
+http://www.opensource.org/licenses/gpl-license.php
+
+2. The Artistic License Version 2.0 -
+http://www.perlfoundation.org/legal/licenses/artistic-2_0.html
+
+3. At your option - any later version of either or both of these licenses.
+
+=cut
